@@ -16,10 +16,7 @@ mod register;
 
 pub use self::{
     cmd::DataCmd,
-    data_exchange::{
-        ChunkDataExchange, ChunkMetadata, DataExchange, HolderMetadata, RegisterDataExchange,
-        StorageLevel,
-    },
+    data_exchange::{ChunkDataExchange, DataExchange, RegisterDataExchange, StorageLevel},
     errors::{Error, Result},
     query::DataQuery,
     register::{RegisterCmd, RegisterRead, RegisterWrite},
@@ -167,7 +164,7 @@ impl QueryResponse {
         match self {
             GetChunk(result) => match result {
                 Ok(_) => false,
-                Err(error) => matches!(*error, ErrorMessage::DataNotFound(_)),
+                Err(error) => matches!(*error, ErrorMessage::ChunkNotFound(_)),
             },
             GetRegister((result, _op_id)) => match result {
                 Ok(_) => false,
