@@ -6,11 +6,12 @@
 // KIND, either express or implied. Please review the Licences for the specific language governing
 // permissions and limitations relating to use of the SAFE Network Software.
 
+use crate::elder_count;
 use crate::messaging::DstLocation;
 use crate::routing::{
     error::{Error, Result},
     network_knowledge::NetworkKnowledge,
-    supermajority, Peer, ELDER_SIZE,
+    supermajority, Peer,
 };
 use itertools::Itertools;
 use std::{cmp, iter};
@@ -56,7 +57,7 @@ pub(crate) async fn delivery_targets(
             if !network_knowledge.is_elder(our_name).await {
                 // We are not Elder - return all the elders of our section,
                 // so the message can be properly relayed through them.
-                let targets: Vec<_> = network_knowledge.authority_provider().await.peers();
+                let targets: Vec<_> = network_knowledge.authority_provider().await.elders_vec();
                 let dg_size = targets.len();
                 Ok((targets, dg_size))
             } else {
@@ -82,10 +83,9 @@ async fn section_candidates(
     if info.prefix() == network_knowledge.prefix().await {
         // Exclude our name since we don't need to send to ourself
         let chosen_section: Vec<_> = info
-            .peers()
-            .iter()
-            .cloned()
+            .elders()
             .filter(|node| &node.name() != our_name)
+            .cloned()
             .collect();
         let dg_size = chosen_section.len();
         return Ok((chosen_section, dg_size));
@@ -106,7 +106,7 @@ async fn candidates(
     let sections = sections
         .iter()
         .sorted_by(|lhs, rhs| lhs.prefix().cmp_distance(&rhs.prefix(), target_name))
-        .map(|info| (info.prefix(), info.elder_count(), info.peers()))
+        .map(|info| (info.prefix(), info.elder_count(), info.elders_vec()))
         .collect_vec();
 
     // let sections = iter::once(&sap)
@@ -116,7 +116,7 @@ async fn candidates(
     // .collect_vec();
 
     // gives at least 1 honest target among recipients.
-    let min_dg_size = 1 + ELDER_SIZE - supermajority(ELDER_SIZE);
+    let min_dg_size = 1 + elder_count() - supermajority(elder_count());
     let mut dg_size = min_dg_size;
     let mut candidates = Vec::new();
     for (idx, (prefix, len, connected)) in sections.iter().enumerate() {
@@ -159,12 +159,12 @@ async fn candidates(
 // Returns a `Peer` for a known node.
 fn get_peer(name: &XorName, network_knowledge: &NetworkKnowledge) -> Option<Peer> {
     match network_knowledge.members().get(name) {
-        Some(info) => Some(info.to_peer()),
+        Some(info) => Some(info.peer().clone()),
         None => network_knowledge
             .section_by_name(name)
             .ok()?
-            .get_addr(name)
-            .map(|addr| Peer::new(*name, addr)),
+            .get_elder(name)
+            .cloned(),
     }
 }
 
@@ -219,7 +219,7 @@ mod tests {
         let name = ed25519::gen_name_with_age(MIN_ADULT_AGE);
         let dst_name = network_knowledge.prefix().await.substituted_in(name);
         let peer = Peer::new(dst_name, gen_addr());
-        let node_state = NodeState::joined(&peer, None);
+        let node_state = NodeState::joined(peer, None);
         let node_state = section_signed(&sk, node_state)?;
         assert!(network_knowledge.update_member(node_state).await);
 
@@ -253,21 +253,16 @@ mod tests {
         let (recipients, dg_size) = delivery_targets(&dst, &our_name, &network_knowledge).await?;
 
         // Send to all our elders except us.
-        let expected_recipients = network_knowledge
+        let expected_recipients: Vec<_> = network_knowledge
             .authority_provider()
             .await
-            .peers()
-            .into_iter()
-            .filter(|peer| peer.name() != our_name);
-        assert_eq!(dg_size, expected_recipients.count());
+            .elders()
+            .filter(|elder| elder.name() != our_name)
+            .cloned()
+            .collect();
 
-        let expected_recipients = network_knowledge
-            .authority_provider()
-            .await
-            .peers()
-            .into_iter()
-            .filter(|peer| peer.name() != our_name);
-        itertools::assert_equal(recipients, expected_recipients);
+        assert_eq!(dg_size, expected_recipients.len());
+        assert_eq!(recipients, expected_recipients);
 
         Ok(())
     }
@@ -315,8 +310,7 @@ mod tests {
 
         // Send to all elders in the dst section
         let expected_recipients = section_auth1
-            .peers()
-            .into_iter()
+            .elders()
             .sorted_by(|lhs, rhs| dst_name.cmp_distance(&lhs.name(), &rhs.name()));
         assert_eq!(dg_size, section_auth1.elder_count());
         itertools::assert_equal(recipients, expected_recipients);
@@ -347,8 +341,7 @@ mod tests {
 
         // Send to all elders in the dst section
         let expected_recipients = elders_info1
-            .peers()
-            .into_iter()
+            .elders()
             .sorted_by(|lhs, rhs| dst_name.cmp_distance(&lhs.name(), &rhs.name()));
         let min_dg_size =
             1 + elders_info1.elder_count() - supermajority(elders_info1.elder_count());
@@ -377,8 +370,7 @@ mod tests {
 
         // Send to all elders in the final dst section
         let expected_recipients = section_auth1
-            .peers()
-            .into_iter()
+            .elders()
             .sorted_by(|lhs, rhs| dst_name.cmp_distance(&lhs.name(), &rhs.name()));
         assert_eq!(dg_size, section_auth1.elder_count());
         itertools::assert_equal(recipients, expected_recipients);
@@ -411,8 +403,7 @@ mod tests {
         let min_dg_size =
             1 + elders_info1.elder_count() - supermajority(elders_info1.elder_count());
         let expected_recipients = elders_info1
-            .peers()
-            .into_iter()
+            .elders()
             .sorted_by(|lhs, rhs| dst_name.cmp_distance(&lhs.name(), &rhs.name()))
             .take(min_dg_size);
 
@@ -437,11 +428,11 @@ mod tests {
         // Send to chosen elder
         assert_eq!(dg_size, 1);
         assert_eq!(
-            Some(recipients[0].addr()),
+            Some(&recipients[0]),
             network_knowledge
                 .authority_provider()
                 .await
-                .get_addr(&dst_name),
+                .get_elder(&dst_name),
         );
 
         Ok(())
@@ -469,7 +460,7 @@ mod tests {
         );
         itertools::assert_equal(
             recipients,
-            network_knowledge.authority_provider().await.peers(),
+            network_knowledge.authority_provider().await.elders(),
         );
 
         Ok(())
@@ -497,7 +488,7 @@ mod tests {
         );
         itertools::assert_equal(
             recipients,
-            network_knowledge.authority_provider().await.peers(),
+            network_knowledge.authority_provider().await.elders(),
         );
 
         Ok(())
@@ -524,7 +515,7 @@ mod tests {
         );
         itertools::assert_equal(
             recipients,
-            network_knowledge.authority_provider().await.peers(),
+            network_knowledge.authority_provider().await.elders(),
         );
 
         Ok(())
@@ -551,7 +542,7 @@ mod tests {
         );
         itertools::assert_equal(
             recipients,
-            network_knowledge.authority_provider().await.peers(),
+            network_knowledge.authority_provider().await.elders(),
         );
 
         Ok(())
@@ -562,11 +553,11 @@ mod tests {
         let prefix1 = Prefix::default().pushed(true);
 
         let (section_auth0, _, secret_key_set) =
-            gen_section_authority_provider(prefix0, ELDER_SIZE);
+            gen_section_authority_provider(prefix0, elder_count());
         let genesis_sk = secret_key_set.secret_key();
         let genesis_pk = genesis_sk.public_key();
 
-        let elders0: Vec<_> = section_auth0.peers();
+        let elders0 = section_auth0.elders_vec();
         let section_auth0 = section_signed(genesis_sk, section_auth0)?;
 
         let chain = SecuredLinkedList::new(genesis_pk);
@@ -574,13 +565,13 @@ mod tests {
         let network_knowledge = NetworkKnowledge::new(genesis_pk, chain, section_auth0, None)?;
 
         for peer in elders0 {
-            let node_state = NodeState::joined(&peer, None);
+            let node_state = NodeState::joined(peer, None);
             let node_state = section_signed(genesis_sk, node_state)?;
             assert!(network_knowledge.update_member(node_state).await);
         }
 
         let (section_auth1, _, secret_key_set) =
-            gen_section_authority_provider(prefix1, ELDER_SIZE);
+            gen_section_authority_provider(prefix1, elder_count());
         let sk1 = secret_key_set.secret_key();
         let pk1 = sk1.public_key();
 
@@ -602,7 +593,7 @@ mod tests {
             .verify_with_chain_and_update(
                 section_auth1,
                 &proof_chain,
-                &network_knowledge.chain().await
+                &network_knowledge.section_chain().await
             )
             .is_ok(),);
 
@@ -614,7 +605,8 @@ mod tests {
     async fn setup_adult() -> Result<(XorName, NetworkKnowledge)> {
         let prefix0 = Prefix::default().pushed(false);
 
-        let (section_auth, _, secret_key_set) = gen_section_authority_provider(prefix0, ELDER_SIZE);
+        let (section_auth, _, secret_key_set) =
+            gen_section_authority_provider(prefix0, elder_count());
         let genesis_sk = secret_key_set.secret_key();
         let genesis_pk = genesis_sk.public_key();
         let section_auth = section_signed(genesis_sk, section_auth)?;
