@@ -7,21 +7,20 @@
 // permissions and limitations relating to use of the SAFE Network Software.
 
 use super::Core;
-use crate::messaging::system::{JoinResponse, Peer, ResourceProofResponse, SystemMsg};
+use crate::messaging::system::{JoinResponse, ResourceProofResponse, SystemMsg};
 use crate::routing::{
     core::{RESOURCE_PROOF_DATA_SIZE, RESOURCE_PROOF_DIFFICULTY},
     ed25519,
     log_markers::LogMarker,
-    peer::PeerUtils,
     routing_api::command::Command,
-    Error, Result,
+    Error, Peer, Result,
 };
 use ed25519_dalek::Verifier;
 use xor_name::XorName;
 
 // Resource signed
 impl Core {
-    pub(crate) fn validate_resource_proof_response(
+    pub(crate) async fn validate_resource_proof_response(
         &self,
         peer_name: &XorName,
         response: ResourceProofResponse,
@@ -34,6 +33,8 @@ impl Core {
 
         if self
             .node
+            .read()
+            .await
             .keypair
             .public
             .verify(&serialized, &response.nonce_signature)
@@ -46,7 +47,7 @@ impl Core {
             .validate_all(&response.nonce, &response.data, response.solution)
     }
 
-    pub(crate) fn send_resource_proof_challenge(&self, peer: &Peer) -> Result<Command> {
+    pub(crate) async fn send_resource_proof_challenge(&self, peer: Peer) -> Result<Command> {
         let nonce: [u8; 32] = rand::random();
         let serialized =
             bincode::serialize(&(peer.name(), &nonce)).map_err(|_| Error::InvalidMessage)?;
@@ -54,14 +55,11 @@ impl Core {
             data_size: RESOURCE_PROOF_DATA_SIZE,
             difficulty: RESOURCE_PROOF_DIFFICULTY,
             nonce,
-            nonce_signature: ed25519::sign(&serialized, &self.node.keypair),
+            nonce_signature: ed25519::sign(&serialized, &self.node.read().await.keypair),
         }));
 
         trace!("{}", LogMarker::SendResourceProofChallenge);
-        self.send_direct_message(
-            (*peer.name(), *peer.addr()),
-            response,
-            *self.section.chain().last_key(),
-        )
+        self.send_direct_message(peer, response, self.network_knowledge.section_key().await)
+            .await
     }
 }
